// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawn.hpp"
#include "world/Map.hpp"

namespace Dawn {
  class Game {
    private:
      std::shared_ptr<Map> map;

    public:
      /**
       * Constructs a new instance of Game, the class majorily responsible for
       * handling all internal dawn functions outside of platform-centric things
       * like windowing and graphics.
       */
      Game();

      /**
       * Initializes the game and all sub managers used by game.
       */
      void init();

      /**
       * Updates the game and all sub managers used by game.
       */
      void update();

      /**
       * Deloads game and all sub managers used by game.
       */
      ~Game();
  };
}